yakumo.nova.v2.security_group_default_rule.Manager

Package yakumo :: Package nova :: Package v2 :: Module security_group_default_rule :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for security group default rules in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for security group default rules in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.security_group_default_rule.Resource |
create(self, cidr=`'``__UNDEF__``'`, lower_port=`'``__UNDEF__``'`, upper_port=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`) Create a security group | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``update``'``]``
| _json_resource_key = ``'``security_group_default_rule``'``
| _json_resources_key = ``'``security_group_default_rules``'``
| _url_resource_path = ``'``/os-security-group-default-rules``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, cidr=`'``__UNDEF__``'`, lower_port=`'``__UNDEF__``'`, upper_port=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`) | source code
Create a security group Parameters: `cidr` (str) - IP range (e.q. '0.0.0.0/0', required) `lower_port` (int) - lower number of destination port `upper_port` (int) - upper number of destination port `protocol` (str) - protocol name ('tcp', 'udp', or 'icmp') Returns: yakumo.nova.v2.security_group_default_rule.Resource Created security group Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('cidr', 'ip_range', mapper.Noop), ('lower
      _port', 'from_port', mapper.Noop), ('upper_port', 'to_port', mapper.No
      op), ('protocol', 'ip_protocol', mapper.Noop),]